use 5.006;
use strict;
use warnings FATAL => 'all';
use Module::Build;

my $builder = Module::Build->new(
    add_to_cleanup     => [ 'App-VOJournal-*' ],
    build_requires => {
        'Test::More' => 0,
    },
    configure_requires => {
        'Module::Build' => 0,
    },
    create_makefile_pl => 'small',
    dist_abstract	=> 'Open a file in vimoutliner to write a journal',
    dist_author         => q{Mathias Weidner <mamawe@cpan.org>},
    dist_version_from   => 'lib/App/VOJournal.pm',
    license             => 'Artistic_2_0',
    module_name         => 'App::VOJournal',
    release_status      => 'stable',
    requires => {
        #'ABC'              => 1.6,
        #'Foo::Bar::Module' => 5.0401,
    },
    script_files	=> [
    	'bin/vojournal'
    ],
);

$builder->create_build_script();
